==> nextcloud-21.0.0-9-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/weather_status/l10n/pl.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Nieznany adres",
    "No result." : "Brak wyników.",
    "Malformed JSON data." : "Nieprawidłowe dane JSON.",
    "Error" : "Błąd",
    "Weather status" : "Stan pogody",
    "Weather status in your dashboard" : "Stan pogody na pulpicie",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Stan pogody zintegrowany z aplikacją Pulpit.\n    Pozycja użytkownika może być określana automatycznie lub ręcznie. Następnie wyświetlana jest prognoza na 6 godzin.\n    Stan pogody można również zintegrować w innych miejscach np. w aplikacji Kalendarz.",
    "Detect location" : "Wykryj lokalizację",
    "Set custom address" : "Ustaw adres własny",
    "Favorites" : "Ulubione",
    "{temperature} {unit} Clear sky at {time}" : "{temperature} {unit} Czyste niebo o {time}",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit} Pochmurno o {time}",
    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit} Przyzwoity dzień o {time}",
    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit} Przyzwoita noc o {time}",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit} Częściowe zachmurzenie o {time}",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit} Mgła o {time}",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit} Lekki deszcz o {time}",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit} Deszcz o {time}",
    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit} Ulewa o {time}",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit} Przelotny deszcz o {time}",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit} Lekki przelotny deszcz o {time}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit} Ulewa przelotna o {time}",
    "More weather for {adr}" : "Więcej pogody dla {adr}",
    "Loading weather" : "Ładowanie pogody",
    "Set location for weather" : "Ustaw lokalizację dla pogody",
    "Remove from favorites" : "Usuń z ulubionych",
    "Add as favorite" : "Dodaj jako ulubione",
    "You are not logged in." : "Nie jesteś zalogowany.",
    "There was an error getting the weather status information." : "Wystąpił błąd podczas pobierania informacji o stanie pogody.",
    "No weather information found" : "Nie znaleziono informacji o pogodzie",
    "Location not found" : "Nie znaleziono lokalizacji",
    "There was an error setting the location address." : "Wystąpił błąd podczas ustawiania adresu lokalizacji.",
    "There was an error setting the location." : "Wystąpił błąd podczas ustawiania lokalizacji.",
    "There was an error saving the mode." : "Wystąpił błąd podczas zapisywania trybu.",
    "There was an error using personal address." : "Wystąpił błąd podczas korzystania z własnego adresu.",
    "Weather status integrated in the dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Stan pogody zintegrowany z aplikacją Pulpit.\nPozycja użytkownika może być określana automatycznie lub ręcznie. Następnie wyświetlana jest prognoza na 6 godzin.\nStan pogody można również zintegrować w innych miejscach np. w aplikacji Kalendarz."
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-22.2.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/weather_status/l10n/pl.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Nieznany adres",
    "No result." : "Brak wyników.",
    "Malformed JSON data." : "Nieprawidłowe dane JSON.",
    "Error" : "Błąd",
    "Weather status" : "Stan pogody",
    "Weather status in your dashboard" : "Stan pogody na pulpicie",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Stan pogody zintegrowany z aplikacją Pulpit.\n    Pozycja użytkownika może być określana automatycznie lub ręcznie. Następnie wyświetlana jest prognoza na 6 godzin.\n    Stan pogody można również zintegrować w innych miejscach np. w aplikacji Kalendarz.",
    "Detect location" : "Wykryj lokalizację",
    "Set custom address" : "Ustaw adres własny",
    "Favorites" : "Ulubione",
    "{temperature} {unit} Clear sky at {time}" : "{temperature} {unit} Czyste niebo do {time}",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit} Pochmurno do {time}",
    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit} Przyzwoity dzień do {time}",
    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit} Przyzwoita noc do {time}",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit} Częściowe zachmurzenie do {time}",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit} Mgła do {time}",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit} Lekki deszcz do {time}",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit} Deszcz do {time}",
    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit} Ulewa do {time}",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit} Przelotny deszcz do {time}",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit} Lekki przelotny deszcz do {time}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit} Ulewa przelotna do {time}",
    "More weather for {adr}" : "Więcej pogody dla {adr}",
    "Loading weather" : "Ładowanie pogody",
    "Set location for weather" : "Ustaw lokalizację dla pogody",
    "Remove from favorites" : "Usuń z ulubionych",
    "Add as favorite" : "Dodaj jako ulubione",
    "You are not logged in." : "Nie jesteś zalogowany.",
    "There was an error getting the weather status information." : "Wystąpił błąd podczas pobierania informacji o stanie pogody.",
    "No weather information found" : "Nie znaleziono informacji o pogodzie",
    "Location not found" : "Nie znaleziono lokalizacji",
    "There was an error setting the location address." : "Wystąpił błąd podczas ustawiania adresu lokalizacji.",
    "There was an error setting the location." : "Wystąpił błąd podczas ustawiania lokalizacji.",
    "There was an error saving the mode." : "Wystąpił błąd podczas zapisywania trybu.",
    "There was an error using personal address." : "Wystąpił błąd podczas korzystania z własnego adresu.",
    "Weather status integrated in the dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Stan pogody zintegrowany z aplikacją Pulpit.\nPozycja użytkownika może być określana automatycznie lub ręcznie. Następnie wyświetlana jest prognoza na 6 godzin.\nStan pogody można również zintegrować w innych miejscach np. w aplikacji Kalendarz."
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
